@@ -1,12 +1,13 @@
 from cProfile import label
 from django import forms
 
-from dcim.models import DeviceType, Manufacturer, ModuleType, Site, Location
+from dcim.models import Device, DeviceType, Manufacturer, ModuleType, Site, Location, Rack
 from netbox.forms import NetBoxModelFilterSetForm
 from utilities.forms import (
     DatePicker, DynamicModelMultipleChoiceField, MultipleChoiceField,
     StaticSelect, TagFilterField, BOOLEAN_WITH_BLANK_CHOICES
 )
+from tenancy.forms import ContactModelFilterForm
 from tenancy.models import Contact, Tenant
 from ..choices import HardwareKindChoices, AssetStatusChoices
 from ..models import Asset, InventoryItemType, InventoryItemGroup, Purchase, Supplier
@@ -35,7 +36,11 @@ class AssetFilterForm(NetBoxModelFilterSetForm):
             'purchase_date_before', 'warranty_start_after', 'warranty_start_before',
             'warranty_end_after', 'warranty_end_before'
         )),
-        ('Location', ('storage_site_id', 'storage_location_id')),
+        ('Location', (
+            'storage_site_id', 'storage_location_id', 'installed_site_id', 
+            'installed_location_id', 'installed_rack_id', 'installed_device_id',
+            'located_site_id', 'located_location_id',
+        )),
     )
 
     status = MultipleChoiceField(
@@ -151,6 +156,7 @@ class AssetFilterForm(NetBoxModelFilterSetForm):
         queryset=Site.objects.all(),
         required=False,
         label='Storage site',
+        help_text="When not in use asset is stored here",
     )
     storage_location_id = DynamicModelMultipleChoiceField(
         queryset=Location.objects.all(),
@@ -160,13 +166,72 @@ class AssetFilterForm(NetBoxModelFilterSetForm):
             'site_id': '$storage_site_id',
         },
         label='Storage location',
-
+        help_text="When not in use asset is stored here",
+    )
+    installed_site_id = DynamicModelMultipleChoiceField(
+        queryset=Site.objects.all(),
+        required=False,
+        label='Installed at site',
+        help_text="Currently installed here",
+    )
+    installed_location_id = DynamicModelMultipleChoiceField(
+        queryset=Location.objects.all(),
+        required=False,
+        null_option='None',
+        query_params={
+            'site_id': '$installed_site_id',
+        },
+        label='Installed at location',
+        help_text="Currently installed here",
+    )
+    installed_rack_id = DynamicModelMultipleChoiceField(
+        queryset=Rack.objects.all(),
+        required=False,
+        null_option='None',
+        query_params={
+            'site_id': '$installed_site_id',
+            'location_id': '$installed_location_id',
+        },
+        label='Installed in rack',
+        help_text="Currently installed here",
+    )
+    installed_device_id = DynamicModelMultipleChoiceField(
+        queryset=Device.objects.all(),
+        required=False,
+        null_option='None',
+        query_params={
+            'site_id': '$installed_site_id',
+            'location_id': '$installed_location_id',
+            'rack_id': '$installed_rack_id',
+        },
+        label='Installed in device',
+    )
+    located_site_id = DynamicModelMultipleChoiceField(
+        queryset=Site.objects.all(),
+        required=False,
+        label='Located at site',
+        help_text="Currently installed or stored here",
+    )
+    located_location_id = DynamicModelMultipleChoiceField(
+        queryset=Location.objects.all(),
+        required=False,
+        null_option='None',
+        query_params={
+            'site_id': '$located_site_id',
+        },
+        label='Located at location',
+        help_text="Currently installed or stored here",
     )
     tag = TagFilterField(model)
 
 
-class SupplierFilterForm(NetBoxModelFilterSetForm):
+class SupplierFilterForm(ContactModelFilterForm, NetBoxModelFilterSetForm):
     model = Supplier
+    fieldsets = (
+        (None, ('q', 'filter_id', 'tag')),
+        ('Contacts', ('contact', 'contact_role', 'contact_group')),
+    )
+
     tag = TagFilterField(model)
 
 
@@ -193,6 +258,11 @@ class PurchaseFilterForm(NetBoxModelFilterSetForm):
 
 class InventoryItemTypeFilterForm(NetBoxModelFilterSetForm):
     model = InventoryItemType
+    manufacturer_id = DynamicModelMultipleChoiceField(
+        queryset=Manufacturer.objects.all(),
+        required=False,
+        label='Manufacturer',
+    )
     inventoryitem_group_id = DynamicModelMultipleChoiceField(
         queryset=InventoryItemGroup.objects.all(),
         required=False,
@@ -203,4 +273,9 @@ class InventoryItemTypeFilterForm(NetBoxModelFilterSetForm):
 
 class InventoryItemGroupFilterForm(NetBoxModelFilterSetForm):
     model = InventoryItemGroup
+    parent_id = DynamicModelMultipleChoiceField(
+        queryset=InventoryItemGroup.objects.all(),
+        required=False,
+        label='Parent group'
+    )
     tag = TagFilterField(model)
